@@ -92,7 +92,7 @@ use PPIx::Regexp::Token::Modifier ();	# For its modifier manipulations.
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.026';
+our $VERSION = '0.036';
 
 =head2 new
 
@@ -425,7 +425,7 @@ sub modifier {
  # prints 'yes'.
 
 This method returns true if the given modifier is asserted for the
-regexp, whether explicitly or by the modifiers passed in in the
+regexp, whether explicitly or by the modifiers passed in the
 C<default_modifiers> argument.
 
 =cut
@@ -438,6 +438,12 @@ sub modifier_asserted {
     );
 }
 
+# This is a kluge for both determining whether the object asserts
+# modifiers (hence the 'ductype') and determining whether the given
+# modifier is actually asserted. The signature is the invocant and the
+# modifier name, which must not be undef. The return is a boolean.
+*__ducktype_modifier_asserted = \&modifier_asserted;
+
 =head2 regular_expression
 
  my $re = PPIx::Regexp->new( 's/(foo)/${1}bar/smx' );
@@ -639,7 +645,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2012 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
