@@ -41,7 +41,7 @@ use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.023';
+our $VERSION = '0.036';
 
 sub _new {
     my ( $class, @children ) = @_;
@@ -387,6 +387,11 @@ sub tokens {
     return ( map { $_->tokens() } $self->elements() );
 }
 
+sub unescaped_content {
+    my ( $self ) = @_;
+    return join '', map { $_->unescaped_content() } $self->elements();
+}
+
 # Help for nav();
 sub _nav {
     my ( $self, $child ) = @_;
@@ -434,7 +439,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
