@@ -34,13 +34,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure };
 
-use PPIx::Regexp::Constant qw{
-    MINIMUM_PERL
-    STRUCTURE_UNKNOWN
-    TOKEN_UNKNOWN
-};
-
-our $VERSION = '0.025';
+our $VERSION = '0.036';
 
 sub __PPIX_LEXER__finalize {
     my ( $self ) = @_;
@@ -73,14 +67,14 @@ sub __PPIX_LEXER__finalize {
 	    $kid->isa( 'PPIx::Regexp::Token::Operator' ) or next;
 	    $kid->content() eq '|' or next;
 	    --$alternations >= 0 and next;
-	    bless $kid, TOKEN_UNKNOWN;
+	    $kid->__error( 'Too many alternatives for switch' );
 	    $rslt++;
 	}
     } else {
 	# If we could not figure out how many alternations were allowed,
 	# it means we did not understand our condition. Rebless
 	# ourselves to the unknown structure and count a parse failure.
-	bless $self, STRUCTURE_UNKNOWN;
+	$self->__error( 'Switch condition not understood' );
 	$rslt++;
     }
 
@@ -106,7 +100,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2012 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
