@@ -28,6 +28,9 @@ or from the replacement side of an s///e. Technically, interpolations
 are also code, but they parse differently and therefore end up in a
 different token.
 
+This token may not appear inside a regex set (i.e. C<(?[ ... ])>. If
+found, it will become a C<PPIx::Regexp::Token::Unknown>.
+
 =head1 METHODS
 
 This class provides the following public methods. Methods not documented
@@ -44,9 +47,10 @@ use warnings;
 use base qw{ PPIx::Regexp::Token };
 
 use PPI::Document;
+use PPIx::Regexp::Constant qw{ COOKIE_REGEX_SET };
 use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.028';
+our $VERSION = '0.036';
 
 sub _new {
     my ( $class, $content ) = @_;
@@ -111,17 +115,13 @@ sub ppi {
     sub __PPIX_TOKEN__post_make {
 	my ( $self, $tokenizer, $arg ) = @_;
 
-	if ( 'HASH' eq ref $arg ) {
-	    foreach my $key ( qw{ perl_version_introduced } ) {
-		exists $arg->{$key}
-		    and $self->{$key} = $arg->{$key};
-	    }
-	}
+	$self->__impose_defaults( $arg, \%default );
 
-	foreach my $key ( keys %default ) {
-	    exists $self->{$key}
-		or $self->{$key} = $default{$key};
-	}
+	# If we're manufacturing objects directly (which is UNSUPPORTED,
+	# but used in t/version.t) we may not have a $tokenizer.
+	$tokenizer
+	    and $tokenizer->cookie( COOKIE_REGEX_SET )
+	    and $self->__error( 'Code token not valid in Regex set' );
 
 	return;
     }
@@ -154,7 +154,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2012 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
