@@ -41,14 +41,30 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-use PPIx::Regexp::Constant qw{ COOKIE_QUOTE TOKEN_LITERAL TOKEN_UNKNOWN };
+use PPIx::Regexp::Constant qw{
+    COOKIE_QUOTE MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
+};
 
-our $VERSION = '0.025';
+our $VERSION = '0.036';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
-my %is_control = map { $_ => 1 } qw{ l u L U Q E };
+{
+    my %version_introduced = (
+	'\\F'	=> '5.015008',
+    );
+
+    sub perl_version_introduced {
+	my ( $self ) = @_;
+	my $content = $self->content();
+	defined $version_introduced{$content}
+	    and return $version_introduced{$content};
+	return MINIMUM_PERL;
+    }
+}
+
+my %is_control = map { $_ => 1 } qw{ l u L U Q E F };
 my %cookie = (
     Q	=> sub { return 1; },
     E	=> undef,
@@ -76,7 +92,10 @@ sub __PPIX_TOKENIZER__regexp {
     # do. If there is no next character, we do not know what to call the
     # back slash.
     my $control = $tokenizer->peek( 1 )
-	or return $reject->( 1, TOKEN_UNKNOWN );
+	or return $reject->( 1, TOKEN_UNKNOWN, {
+		error => 'Trailing back slash'
+	    },
+	);
 
     # We reject any escapes that do not represent controls.
     $is_control{$control} or return $reject->( 2 );
@@ -119,7 +138,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2012 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
