@@ -34,7 +34,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.022';
+our $VERSION = '0.036';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -44,17 +44,8 @@ sub perl_version_introduced {
     return '5.005';
 }
 
-sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
-
-    # The optional escapes are because any non-open-bracket character
-    # may be the delimiter of the regular expression.
-    if ( my $accept = $tokenizer->find_regexp(
-	    qr{ \A \\? \? \\? > }smx ) ) {
-	return $accept;
-    }
-
-    return;
+sub __defining_string {
+    return '?>';
 }
 
 1;
@@ -72,7 +63,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
