@@ -35,7 +35,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.028';
+our $VERSION = '0.036';
 
 sub perl_version_introduced {
 #   my ( $self ) = @_;
@@ -45,6 +45,8 @@ sub perl_version_introduced {
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+=begin comment
+
 sub __PPIX_TOKENIZER__regexp {
     my ( $class, $tokenizer, $character ) = @_;
 
@@ -68,6 +70,24 @@ sub __PPIX_TOKENIZER__regexp {
 
 }
 
+=end comment
+
+=cut
+
+sub __defining_string {
+    return (
+	{ suffix => '(' },
+	'?',
+    );
+}
+
+sub __match_setup {
+    my ( $class, $tokenizer ) = @_;
+    $tokenizer->expect( qw{ PPIx::Regexp::Token::Condition } );
+    return;
+}
+
+
 1;
 
 __END__
@@ -83,7 +103,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2012 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
