@@ -34,9 +34,11 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-use PPIx::Regexp::Constant qw{ COOKIE_CLASS MINIMUM_PERL };
+use PPIx::Regexp::Constant qw{
+    COOKIE_CLASS COOKIE_REGEX_SET MINIMUM_PERL TOKEN_UNKNOWN
+};
 
-our $VERSION = '0.025';
+our $VERSION = '0.036';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -86,14 +88,77 @@ my %extra_ordinary = map { $_ => 1 }
 #   ^ -> Token::Assertion
 #   | - -> Token::Operator
 
+my %regex_set_operator = map { $_ => 1 } qw{ & + | - ^ ! };
+
+# The regex for the extended white space available under regex sets in
+# Perl 5.17.8 and in general in perl 5.17.9. I have been unable to get
+# this to work under Perl 5.6.2, so for that we fall back to ASCII white
+# space. The stringy eval is because I have been unable to get
+# satisfaction out of either interpolated characters (in general) or
+# eval-ed "\N{U+...}" (under 5.6.2) or \x{...} (ditto).
+#
+# See PPIx::Regexp::Structure::RegexSet for the documentation of this
+# mess.
+# my $white_space_re = $] >= 5.008 ?
+# 'qr< \\A [\\s\\N{U+0085}\\N{U+200E}\\N{U+200F}\\N{U+2028}\\N{U+2029}]+ >smx' :
+# 'qr< \\A \\s+ >smx';
+#
+# RT #91798
+# The above turns out to be wrong, because \s matches too many
+# characters. We need the following to get the right match. Note that
+# \cK was added experimentally in 5.17.0 and made it into 5.18. The \N{}
+# characters were NOT added (as I originally thought) but were simply
+# made characters that generated warnings when escaped, in preparation
+# for adding them. When they actually get added, I will have to add back
+# the trinary operator. Sigh.
+my $white_space_re = 'qr< \A [\t\n\cK\f\r ] >smx';
+$white_space_re = eval $white_space_re;  ## no critic (ProhibitStringyEval)
+
+my %regex_pass_on = map { $_ => 1 } qw{ [ ] ( ) $ \ };
+
 sub __PPIX_TOKENIZER__regexp {
     my ( $class, $tokenizer, $character, $char_type ) = @_;
 
-    # Handle the characters that may or may not be literals depending on
-    # whether or not we are in a character class.
-    if ( my $class = $double_agent{$character} ) {
-	my $inx = $tokenizer->cookie( COOKIE_CLASS ) ? 1 : 0;
-	return $class->[$inx];
+    if ( $tokenizer->cookie( COOKIE_REGEX_SET ) ) {
+	# If we're inside a regex set no literals are allowed, but not
+	# all characters that get here are seen as literals.
+
+	$regex_set_operator{$character}
+	    and return $tokenizer->make_token(
+	    length $character, 'PPIx::Regexp::Token::Operator' );
+
+	my $accept;
+
+	$accept = $tokenizer->find_regexp( $white_space_re )
+	    and return $tokenizer->make_token(
+		$accept, 'PPIx::Regexp::Token::Whitespace' );
+
+	$accept = _escaped( $tokenizer, $character )
+	    and return $accept;
+
+	$regex_pass_on{$character}
+	    and return;
+
+	# At this point we have a single character which is poised to be
+	# interpreted as a literal. These are not legal in a regex set
+	# except when also in a bracketed class.
+	return $tokenizer->cookie( COOKIE_CLASS ) ?
+	    length $character :
+	    $tokenizer->make_token(
+		length $character, TOKEN_UNKNOWN, {
+			error	=> 'Literal not valid in Regex set',
+		    },
+		);
+
+    } else {
+
+	# Otherwise handle the characters that may or may not be
+	# literals depending on whether or not we are in a character
+	# class.
+	if ( my $class = $double_agent{$character} ) {
+	    my $inx = $tokenizer->cookie( COOKIE_CLASS ) ? 1 : 0;
+	    return $class->[$inx];
+	}
     }
 
     # If /x is in effect _and_ we are not inside a character class, \s
@@ -102,7 +167,7 @@ sub __PPIX_TOKENIZER__regexp {
     if ( $tokenizer->modifier( 'x' ) &&
 	! $tokenizer->cookie( COOKIE_CLASS ) ) {
 	my $accept;
-	$accept = $tokenizer->find_regexp( qr{ \A \s+ }smx )
+	$accept = $tokenizer->find_regexp( $white_space_re )
 	    and return $tokenizer->make_token(
 		$accept, 'PPIx::Regexp::Token::Whitespace' );
 	$accept = $tokenizer->find_regexp(
@@ -114,6 +179,17 @@ sub __PPIX_TOKENIZER__regexp {
 	    and return 1;
     }
 
+    my $accept;
+    $accept = _escaped( $tokenizer, $character )
+	and return $accept;
+
+    # All other characters which are not extra ordinary get accepted.
+    $extra_ordinary{$character} or return 1;
+
+    return;
+}
+
+
 =begin comment
 
 The following is from perlop:
@@ -130,32 +206,32 @@ The following is from perlop:
 
 =cut
 
-    # Recognize all the escaped constructions that generate literal
-    # characters in one gigantic regexp. Technically \1.. through \7..
-    # are octal literals too, but we can not disambiguate these from
-    # back references until we know how many there are. So the lexer
-    # gets another dirty job.
-    if ( $character eq '\\' ) {
-	if ( my $accept = $tokenizer->find_regexp(
-		qr< \A \\ (?:
-		    [^\w\s] |		# delimiters/metas
-		    [tnrfae] |		# C-style escapes
-		    0 [01234567]{0,2} |	# octal
-#		    [01234567]{1,3} |	# made from backref by lexer
-		    c [][[:alpha:]\@\\^_?] |	# control characters
-		    x (?: \{ [[:xdigit:]]* \} | [[:xdigit:]]{0,2} ) | # hex
-		    o [{] [01234567]+ [}] |	# octal as of 5.13.3
-##		    N (?: \{ (?: [[:alpha:]] [\w\s:()-]* | # must begin w/ alpha
-##			U [+] [[:xdigit:]]+ ) \} ) |	# unicode
-		    N (?: [{] (?= \D ) [^\}]+ [}] )	# unicode
-		) >smx ) ) {
-	    return $accept;
-	}
+# Recognize all the escaped constructions that generate literal
+# characters in one gigantic regexp. Technically \1.. through \7.. are
+# octal literals too, but we can not disambiguate these from back
+# references until we know how many there are. So the lexer gets another
+# dirty job.
+sub _escaped {
+    my ( $tokenizer, $character ) = @_;
+
+    $character eq '\\'
+	or return;
+
+    if ( my $accept = $tokenizer->find_regexp(
+	    qr< \A \\ (?:
+		[^\w\s] |		# delimiters/metas
+		[tnrfae] |		# C-style escapes
+		0 [01234567]{0,2} |	# octal
+#		[01234567]{1,3} |	# made from backref by lexer
+		c [][[:alpha:]\@\\^_?] |	# control characters
+		x (?: \{ [[:xdigit:]]* \} | [[:xdigit:]]{0,2} ) | # hex
+		o [{] [01234567]+ [}] |	# octal as of 5.13.3
+##		N (?: \{ (?: [[:alpha:]] [\w\s:()-]* | # must begin w/ alpha
+##		    U [+] [[:xdigit:]]+ ) \} ) |	# unicode
+		N (?: [{] (?= \D ) [^\}]+ [}] )	# unicode
+	    ) >smx ) ) {
+	return $accept;
     }
-
-    # All other characters which are not extra ordinary get accepted.
-    $extra_ordinary{$character} or return 1;
-
     return;
 }
 
@@ -334,7 +410,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2012 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
