@@ -37,7 +37,14 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-our $VERSION = '0.023';
+use PPIx::Regexp::Constant qw{ COOKIE_REGEX_SET MINIMUM_PERL };
+
+our $VERSION = '0.036';
+
+sub perl_version_introduced {
+    my ( $self ) = @_;
+    return $self->{perl_version_introduced};
+}
 
 sub significant {
     return;
@@ -68,6 +75,33 @@ sub __PPIX_TOKENIZER__regexp {
 
 =cut
 
+sub __PPIX_TOKEN__post_make {
+    my ( $self, $tokenizer, $arg ) = @_;
+
+    $self->{perl_version_introduced} = MINIMUM_PERL;
+
+    # RT #91798.
+    # TODO the above needs to be replaced by the following (suitably
+    # modified) when the non-ASCII white space characters are finally
+    # recognized by Perl.
+
+=begin comment
+
+    if ( ord $self->content() < 128 ) {
+	$self->{perl_version_introduced} = MINIMUM_PERL;
+    } elsif ( $tokenizer && $tokenizer->cookie( COOKIE_REGEX_SET ) ) {
+	$self->{perl_version_introduced} = '5.017008';
+    } else {
+	$self->{perl_version_introduced} = '5.017009';
+    }
+
+=end comment
+
+=cut
+
+    return;
+}
+
 1;
 
 __END__
@@ -83,7 +117,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
