@@ -42,13 +42,13 @@ use PPIx::Regexp::Token::Whitespace		();
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.026';
+our $VERSION = '0.036';
 
 {
     # Names of classes containing tokenization machinery. There are few
     # known ordering requirements, since each class recognizes its own,
     # and I have tried to prevent overlap. Absent such constraints, the
-    # order is in percieved frequency of acceptance, to keep the search
+    # order is in perceived frequency of acceptance, to keep the search
     # as short as possible. If I were conscientious I would gather
     # statistics on this.
     my @classes = (	# TODO make readonly when acceptable way appears
@@ -256,6 +256,10 @@ sub encoding {
 
 sub expect {
     my ( $self, @args ) = @_;
+
+    @args
+	or return;
+
     $self->{expect_next} = [
 	map { m/ \A PPIx::Regexp:: /smx ? $_ : 'PPIx::Regexp::' . $_ }
 	@args
@@ -334,6 +338,11 @@ sub find_regexp {
     return wantarray ? ( $-[0] + 0, $+[0] + 0 ) : $+[0] + 0;
 }
 
+sub get_start_delimiter {
+    my ( $self ) = @_;
+    return $self->{delimiter_start};
+}
+
 sub get_token {
     my ( $self ) = @_;
 
@@ -531,7 +540,10 @@ sub __PPIX_TOKENIZER__init {
     $tokenizer->{mode} = 'kaput';
     $tokenizer->{content} =~ m/ \A \s* ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
 	or return $tokenizer->make_token(
-	    length( $tokenizer->{content} ), TOKEN_UNKNOWN );
+	    length( $tokenizer->{content} ), TOKEN_UNKNOWN, {
+		error	=> 'Tokenizer found illegal first characters',
+	    },
+	);
 #   my ( $type, $white, $delim ) = ( $1, $2, $3 );
     my ( $type, $white ) = ( $1, $2 );
     my $start_pos = defined $-[1] ? $-[1] :
@@ -630,7 +642,10 @@ sub __PPIX_TOKEN_FALLBACK__regexp {
     }
 
     # Any normal character is unknown.
-    return $tokenizer->make_token( 1, TOKEN_UNKNOWN );
+    return $tokenizer->make_token( 1, TOKEN_UNKNOWN, {
+	    error	=> 'Tokenizer found unexpected literal',
+	},
+    );
 }
 
 sub __PPIX_TOKEN_FALLBACK__repl {
@@ -949,6 +964,8 @@ This method inserts a given class at the head of the token scan, for the
 next iteration only. More than one class can be specified. Class names
 can be abbreviated by removing the leading 'PPIx::Regexp::'.
 
+If no class is specified, this method does nothing.
+
 The expectation lasts from the next time L</get_token> is called until
 the next time L<make_token> makes a significant token, or until the next
 C<expect> call if that is done sooner.
@@ -988,6 +1005,13 @@ This method returns the offset from the current position in the content
 string to the matching delimiter (which will always be positive), or
 undef if no match can be found.
 
+=head2 get_start_delimiter
+
+ my $start_delimiter = $tokenizer->get_start_delimiter();
+
+This method is used by tokenizers to access the start delimiter for the
+regular expression.
+
 =head2 get_token
 
  my $token = $tokenizer->make_token( 3 );
@@ -1126,7 +1150,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2012 by Thomas R. Wyant, III
+Copyright (C) 2009-2014 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
